subroutine hdfout(problem,nframe,agrid)
! 
! AUTHORS:
!     James M. Stone, Princeton Univeristy
!     Thomas Gardiner, University of Maryland
!     Peter J. Teuben, University of Maryland
!     John Hawley, University of Virginia
!
!     This software was produced with support from NSF Grant AST-0113571 
!
! Copyright 2003 James M. Stone, Thomas Gardiner,
!                Peter Teuben, John F. Hawley
!
!   This program is free software; you can redistribute it and/or modify
!   it under the terms of the GNU General Public License as published by
!   the Free Software Foundation.
!
!   This program is distributed in the hope that it will be useful,
!   but WITHOUT ANY WARRANTY; without even the implied warranty of
!   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
!   GNU General Public License for more details.
!

use athenadefs
IMPLICIT NONE
type (grid) agrid

character(*) problem
integer nframe

!-------------------------------------------------------------------


end subroutine hdfout

subroutine tabout(problem,nframe,agrid)
use athenadefs
IMPLICIT NONE
type (grid) agrid

character(*) problem
integer nframe

integer :: iounit = 40
integer :: i
character(len=50) ::  fname

!-------------------------------------------------------------------

write(fname,FMT="(a,'.',i3.3,'.tab')") TRIM(problem),nframe

open(unit=iounit,file=fname,form='formatted',err=600)
write(unit=iounit,FMT="('# Nx = ',i7)") agrid%nx1
write(unit=iounit,FMT="('# xsize = ',g10.4)") agrid%x1(agrid%ie+1) - agrid%x1(agrid%is)
write(unit=iounit,FMT="('# time  = ',g10.4)") agrid%time
write(unit=iounit,FMT="('# ')")

if (mhd .and. adiabatic) then
  write(unit=iounit,FMT="('# zone# x1 d M1 M2 M3 E B1 B2 B3')")
else if (mhd) then
  write(unit=iounit,FMT="('# zone# x1 d M1 M2 M3 B1 B2 B3')")
else if (adiabatic) then
  write(unit=iounit,FMT="('# zone# x1 d M1 M2 M3 E')")
else
  write(unit=iounit,FMT="('# zone# x1 d M1 M2 M3')")
endif
write(unit=iounit,FMT="('# ')")

if (mhd .and. adiabatic) then
  do i=agrid%is, agrid%ie
     write(unit=iounit,FMT="(i7,9(1x,g12.6))") i, agrid%x1(i), agrid%d(i) &
       , agrid%m1(i), agrid%m2(i), agrid%m3(i), agrid%e(i)&
       , agrid%b1(i), agrid%b2(i), agrid%b3(i)
  enddo
else if (mhd) then
  do i=agrid%is, agrid%ie
     write(unit=iounit,FMT="(i7,8(1x,g12.6))") i, agrid%x1(i), agrid%d(i) &
       , agrid%m1(i), agrid%m2(i), agrid%m3(i) &
       , agrid%b1(i), agrid%b2(i), agrid%b3(i)
  enddo
else if (adiabatic) then
  do i=agrid%is, agrid%ie
     write(unit=iounit,FMT="(i7,7(1x,g12.6))") i, agrid%x1(i), agrid%d(i) &
       , agrid%m1(i), agrid%m2(i), agrid%m3(i), agrid%e(i)
  enddo
else
  do i=agrid%is, agrid%ie
     write(unit=iounit,FMT="(i7,6(1x,g12.6))") i, agrid%x1(i), agrid%d(i) &
       , agrid%m1(i), agrid%m2(i), agrid%m3(i)
  enddo
endif

close(unit=iounit)
return

600 write(*,FMT="('Error opening tabular file, returning...')")
return

end subroutine tabout

subroutine binout(problem,nframe,agrid)
use athenadefs
IMPLICIT NONE
type (grid) agrid

character(*) problem
integer nframe

integer :: iounit = 41
integer :: is, ie, nzones, num_vars
character(len=50) ::  fname

real (real4), dimension(:), allocatable :: outdat
real (real4) :: gam_1, isoc

!-------------------------------------------------------------------
!
! write out a binary file containing the run data
! the file is written in terms of 4 byte reals regardless 
! of the representation used in the calculation
! since the intent is to generate a binary file for
! use in (say) idl or other subsequent data analysis
! and real*4 is sufficient for that
!

write(fname,FMT="(a,'.',i3.3,'.bin')") TRIM(problem),nframe

is=agrid%is
ie=agrid%ie
nzones=ie-is+1

open(unit=iounit,file=fname,form='unformatted',err=600)

allocate(outdat(nzones))

if (mhd) then
  if (adiabatic) then
    num_vars=8
  else
    num_vars=7
  endif
else
  if (adiabatic) then
    num_vars=5
  else
    num_vars=4
  endif
endif

write(iounit) nzones,num_vars
if (adiabatic) then
  gam_1 = agrid%gamma -1.
  isoc = 0.
  write(iounit) gam_1,isoc
else
  gam_1 = 0.
  isoc = ISOTHERMAL_C
  write(iounit) gam_1,isoc
endif

outdat = agrid%x1(is:ie)
write(iounit) outdat
outdat = agrid%d(is:ie)
write(iounit) outdat
outdat = agrid%m1(is:ie)
write(iounit) outdat
outdat = agrid%m2(is:ie)
write(iounit) outdat
outdat = agrid%m3(is:ie)
write(iounit) outdat
if (adiabatic) then 
  outdat = agrid%e(is:ie)
  write(iounit) outdat
endif
if (mhd) then
  outdat = agrid%b2(is:ie)
  write(iounit) outdat
  outdat = agrid%b3(is:ie)
  write(iounit) outdat
  outdat = agrid%b1(is:ie)
  write(iounit) outdat
endif

close(unit=iounit)
deallocate(outdat)
return

600 write(*,FMT="('Error opening binary output file, returning...')")
return

end subroutine binout

subroutine hstout(problem,nframe,agrid)
use athenadefs
IMPLICIT NONE
type (grid) agrid

character(*) problem
integer nframe

! LOCALS

character(len=50) ::  fname
integer :: iounit = 42
integer :: is, ie
real (r_kind) :: mass, energy, xke, yke, zke, magx, magy, magz, dvol


!-------------------------------------------------------------------

write(fname,FMT="(a,'.hst')") TRIM(problem)

if (nframe .EQ. 0) then
  open (unit=iounit, file=fname, status='REPLACE', form='FORMATTED', err=600)
else
  open (unit=iounit, file=fname, status='OLD', position='APPEND',form='FORMATTED',err=601)
endif

is = agrid%is
ie = agrid%ie
dvol = ABS(agrid%dx)

mass = SUM(agrid%d(is:ie)) *dvol
xke = 0.5* SUM( (agrid%m1(is:ie)**2/agrid%d(is:ie)) ) *dvol
yke = 0.5* SUM( (agrid%m2(is:ie)**2/agrid%d(is:ie)) ) *dvol
zke = 0.5* SUM( (agrid%m3(is:ie)**2/agrid%d(is:ie)) ) *dvol
if (adiabatic) energy = SUM(agrid%e(is:ie)) *dvol
if (mhd) then
  magx = 0.5* SUM( (agrid%b1(is:ie)**2) ) *dvol
  magy = 0.5* SUM( (agrid%b2(is:ie)**2) ) *dvol
  magz = 0.5* SUM( (agrid%b3(is:ie)**2) ) *dvol
endif

if (adiabatic .and. mhd) then
  write(unit=iounit,FMT="(10(1x,g12.6))") agrid%time, agrid%dt, mass, energy, xke, yke, zke, magx, magy, magz
else if (mhd) then
  write(unit=iounit,FMT="(9(1x,g12.6))") agrid%time, agrid%dt, mass, xke, yke, zke, magx, magy, magz
else if (adiabatic) then
  write(unit=iounit,FMT="(7(1x,g12.6))") agrid%time, agrid%dt, mass, energy, xke, yke, zke
else
  write(unit=iounit,FMT="(6(1x,g12.6))") agrid%time, agrid%dt, mass, xke, yke, zke
endif

close(iounit)
return

600 write(*,FMT="('Error on initial open of history file, returning...')")
return

601 write(*,FMT="('Error on subsequent open of history file, returning...')")
return

end subroutine hstout
