subroutine eigen_adb_hyd_cons(NX,NVAR,gamma,vx,vy,vz,h,lambda,rem,lem)
! 
! AUTHORS:
!     James M. Stone, Princeton Univeristy
!     Thomas Gardiner, University of Maryland
!     Peter J. Teuben, University of Maryland
!     John Hawley, University of Virginia
!
!     This software was produced with support from NSF Grant AST-0113571 
!
! Copyright 2003 James M. Stone, Thomas Gardiner,
!                Peter Teuben, John F. Hawley
!
!   This program is free software; you can redistribute it and/or modify
!   it under the terms of the GNU General Public License as published by
!   the Free Software Foundation.
!
!   This program is distributed in the hope that it will be useful,
!   but WITHOUT ANY WARRANTY; without even the implied warranty of
!   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
!   GNU General Public License for more details.
!

use athenadefs
!
! hydro adiabatic Roe eigenvalues and eigenvectors
!
integer NX, NVAR
real (r_kind), intent(IN) :: gamma
real (r_kind), dimension(NX), target, intent(IN) :: vx, vy, vz, h
real (r_kind), intent(OUT), dimension(NVAR,NX) :: lambda
real (r_kind), intent(OUT), dimension(NVAR,NVAR,NX) :: rem, lem
!
! LOCALS
!
real (r_kind), dimension(:), allocatable :: cs, vsq, norm

! compute eigenvalues and eigenmatrices for  averages
! assume adiabatic hydro
!
!-----------------------------------------------------------------------

allocate(norm(NX))
allocate(vsq(NX))
allocate(cs(NX))

vsq = vx*vx+vy*vy+vz*vz
cs = sqrt((gamma-1.)*MAX((h-.5_r_kind*vsq), TINY_NUMBER))
norm = 0.5/(cs*cs)

!
! eigenvalues
!
!
  lambda(1,:) = vx - cs
  lambda(2,:) = vx
  lambda(3,:) = vx
  lambda(4,:) = vx
  lambda(5,:) = vx + cs
!
! eigenmatrix
!
  rem = 0.
  
  rem(1,1,:) = 1.
  rem(1,2,:) = vx - cs
  rem(1,3,:) = vy
  rem(1,4,:) = vz
  rem(1,5,:) = h - vx*cs

  rem(2,3,:) = 1.0
  rem(2,5,:) = vy

  rem(3,4,:) = 1.0
  rem(3,5,:) = vz

  rem(4,1,:) = 1.
  rem(4,2,:) = vx
  rem(4,3,:) = vy
  rem(4,4,:) = vz
  rem(4,5,:) = 0.5_r_kind * vsq

  rem(5,1,:) = 1.
  rem(5,2,:) = vx + cs
  rem(5,3,:) = vy
  rem(5,4,:) = vz
  rem(5,5,:) = h + vx*cs

!
! left eigenmatrix
!

  lem(1,1,:) = norm*(0.5*(gamma-1.)*vsq + vx*cs)
  lem(2,1,:) = -norm*((gamma-1.)*vx + cs)
  lem(3,1,:) = -norm*(gamma-1.)*vy
  lem(4,1,:) = -norm*(gamma-1.)*vz
  lem(5,1,:) = norm*(gamma-1.)

  lem(1,2,:) = -vy
  lem(2,2,:) = 0.0
  lem(3,2,:) = 1.0
  lem(4,2,:) = 0.0
  lem(5,2,:) = 0.0

  lem(1,3,:) = -vz
  lem(2,3,:) = 0.0
  lem(3,3,:) = 0.0
  lem(4,3,:) = 1.0
  lem(5,3,:) = 0.0

  lem(1,4,:) = 1.-norm*(gamma-1.)*vsq
  lem(2,4,:) = (gamma-1.)*vx/(cs*cs)
  lem(3,4,:) = (gamma-1.)*vy/(cs*cs)
  lem(4,4,:) = (gamma-1.)*vz/(cs*cs)
  lem(5,4,:) = -(gamma-1.)/(cs*cs)

  lem(1,5,:) = norm*(0.5_r_kind*(gamma-1.)*vsq - vx*cs)
  lem(2,5,:) = -norm*((gamma-1.)*vx - cs)
  lem(3,5,:) = lem(3,1,:)
  lem(4,5,:) = lem(4,1,:)
  lem(5,5,:) = lem(5,1,:)

deallocate(cs,norm,vsq)

return
end subroutine eigen_adb_hyd_cons
