subroutine eigen_adb_hyd_prim(NX,NVAR,gamma,W,lambda,rem,lem)
! 
! AUTHORS:
!     James M. Stone, Princeton Univeristy
!     Thomas Gardiner, University of Maryland
!     Peter J. Teuben, University of Maryland
!     John Hawley, University of Virginia
!
!     This software was produced with support from NSF Grant AST-0113571 
!
! Copyright 2003 James M. Stone, Thomas Gardiner,
!                Peter Teuben, John F. Hawley
!
!   This program is free software; you can redistribute it and/or modify
!   it under the terms of the GNU General Public License as published by
!   the Free Software Foundation.
!
!   This program is distributed in the hope that it will be useful,
!   but WITHOUT ANY WARRANTY; without even the implied warranty of
!   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
!   GNU General Public License for more details.
!

use athenadefs
IMPLICIT NONE
!
! hydro adiabatic Roe eigenvalues and eigenvectors
!
integer NX, NVAR
real (r_kind), intent(IN) :: gamma
real (r_kind), dimension(NX,NVAR), target, intent(IN) ::  W
real (r_kind), intent(OUT), dimension(NVAR,NX) :: lambda
real (r_kind), intent(OUT), dimension(NVAR,NVAR,NX) :: rem, lem
!
! LOCALS
!

real (r_kind), dimension(:), allocatable :: cs
real (r_kind), dimension(:), pointer :: d, vx, vy, vz, p


! compute eigenvalues and eigenmatrices for  averages
! assume adiabatic hydro
!
!-----------------------------------------------------------------------

d=>w(:,1); vx=>w(:,2); vy=>w(:,3); vz=>w(:,4); p=>w(:,5)

allocate(cs(nx))
cs=sqrt(gamma*p/d)

!
! eigenvalues
!
!
  lambda(1,:) = vx - cs
  lambda(2,:) = vx
  lambda(3,:) = vx
  lambda(4,:) = vx
  lambda(5,:) = vx + cs
!
! right eigenmatrix
!

  rem(1,1,:) = 1.
  rem(1,2,:) = -cs/d
  rem(1,3,:) = 0.
  rem(1,4,:) = 0.
  rem(1,5,:) = cs*cs

  rem(2,1,:) = 1.0
  rem(2,2,:) = 0.0
  rem(2,3,:) = 0.0
  rem(2,4,:) = 0.0
  rem(2,5,:) = 0.0

  rem(3,1,:) = 0.
  rem(3,2,:) = 0.
  rem(3,3,:) = 1.
  rem(3,4,:) = 0.
  rem(3,5,:) = 0.

  rem(4,1,:) = 0.
  rem(4,2,:) = 0.
  rem(4,3,:) = 0.
  rem(4,4,:) = 1.
  rem(4,5,:) = 0.

  rem(5,1,:) = 1.
  rem(5,2,:) = -rem(1,2,:)
  rem(5,3,:) = 0.
  rem(5,4,:) = 0.
  rem(5,5,:) =  rem(1,5,:)
!
! left eigenmatrix
!

  lem(1,1,:) = 0.0
  lem(2,1,:) = -.5_r_kind*d/cs
  lem(3,1,:) = 0.0
  lem(4,1,:) = 0.0
  lem(5,1,:) =  .5_r_kind/(cs*cs)

  lem(1,2,:) = 1.0
  lem(2,2,:) = 0.0
  lem(3,2,:) = 0.0
  lem(4,2,:) = 0.0
  lem(5,2,:) = -1./(cs*cs)

  lem(1,3,:) = 0.0
  lem(2,3,:) = 0.0
  lem(3,3,:) = 1.0
  lem(4,3,:) = 0.0
  lem(5,3,:) = 0.0

  lem(1,4,:) = 0.0
  lem(2,4,:) = 0.0
  lem(3,4,:) = 0.0
  lem(4,4,:) = 1.0
  lem(5,4,:) = 0.

  lem(1,5,:) = 0.
  lem(2,5,:) = -lem(2,1,:)
  lem(3,5,:) = 0.
  lem(4,5,:) = 0.
  lem(5,5,:) =  lem(5,1,:)

  deallocate(cs)

NULLIFY(d,vx,vy,vz,p)

return
end subroutine eigen_adb_hyd_prim
