subroutine eigen_iso_hyd_cons(NX,NVAR,d,vx,vy,vz,lambda,rem,lem)
!
! hydro isothermal Roe eigenvalues and eigenvectors
!
! AUTHORS:
!     James M. Stone, Princeton Univeristy
!     Thomas Gardiner, University of Maryland
!     Peter J. Teuben, University of Maryland
!     John Hawley, University of Virginia
!
!     This software was produced with support from NSF Grant AST-0113571 
!
! Copyright 2003 James M. Stone, Thomas Gardiner,
!                Peter Teuben, John F. Hawley
!
!   This program is free software; you can redistribute it and/or modify
!   it under the terms of the GNU General Public License as published by
!   the Free Software Foundation.
!
!   This program is distributed in the hope that it will be useful,
!   but WITHOUT ANY WARRANTY; without even the implied warranty of
!   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
!   GNU General Public License for more details.
!

use athenadefs
IMPLICIT NONE

integer NX, NVAR
real (r_kind), dimension(NX), intent(IN) :: d, vx, vy, vz
real (r_kind), dimension(NVAR,NX), intent(OUT) :: lambda
real (r_kind), dimension(NVAR,NVAR,NX), intent(OUT) :: rem, lem
!
! LOCALS
!

! compute eigenvalues and eigenmatrices for  averages
! isothermal hydro
!
!-----------------------------------------------------------------------
!
! eigenvalues
!
!
  lambda(1,:) = vx - ISOTHERMAL_C
  lambda(2,:) = vx 
  lambda(3,:) = vx
  lambda(4,:) = vx + ISOTHERMAL_C
!
! right eigenmatrix
!

  rem(1,1,:) = 1.
  rem(1,2,:) = vx - ISOTHERMAL_C
  rem(1,3,:) = vy
  rem(1,4,:) = vz

  rem(2,1,:) = 0.
  rem(2,2,:) = 0.
  rem(2,3,:) = 1.
  rem(2,4,:) = 0.

  rem(3,1,:) = 0.
  rem(3,2,:) = 0.
  rem(3,3,:) = 0.
  rem(3,4,:) = 1.

  rem(4,1,:) = 1.
  rem(4,2,:) = vx + ISOTHERMAL_C
  rem(4,3,:) = vy
  rem(4,4,:) = vz
!
! left eigenmatrix
!

  lem(1,1,:) =  .5*(1.+vx/ISOTHERMAL_C)
  lem(2,1,:) = -.5/ISOTHERMAL_C
  lem(3,1,:) =   0.
  lem(4,1,:) =   0.

  lem(1,2,:) = -vy
  lem(2,2,:) =  0.
  lem(3,2,:) =  1.
  lem(4,2,:) =  0.

  lem(1,3,:) = -vz
  lem(2,3,:) =  0.
  lem(3,3,:) =  0.
  lem(4,3,:) =  1.

  lem(1,4,:) =  .5*(1. - vx/ISOTHERMAL_C)
  lem(2,4,:) =  .5/ISOTHERMAL_C
  lem(3,4,:) =  0.
  lem(4,4,:) =  0.

return
end subroutine eigen_iso_hyd_cons

