subroutine eigen_iso_hyd_prim(NX,NVAR,W,lambda,rem,lem)
!
! hydro isothermal Roe eigenvalues and eigenvectors
! 
! AUTHORS:
!     James M. Stone, Princeton Univeristy
!     Thomas Gardiner, University of Maryland
!     Peter J. Teuben, University of Maryland
!     John Hawley, University of Virginia
!
!     This software was produced with support from NSF Grant AST-0113571 
!
! Copyright 2003 James M. Stone, Thomas Gardiner,
!                Peter Teuben, John F. Hawley
!
!   This program is free software; you can redistribute it and/or modify
!   it under the terms of the GNU General Public License as published by
!   the Free Software Foundation.
!
!   This program is distributed in the hope that it will be useful,
!   but WITHOUT ANY WARRANTY; without even the implied warranty of
!   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
!   GNU General Public License for more details.
!
!

use athenadefs
IMPLICIT NONE

integer NX, NVAR
real (r_kind), dimension(NX,NVAR), target, intent(IN) ::  W
real (r_kind), dimension(NVAR,NX), intent(OUT) :: lambda
real (r_kind), dimension(NVAR,NVAR,NX), intent(OUT) :: rem, lem
!
! LOCALS
!
real (r_kind), dimension(:), pointer :: d, vx

! compute eigenvalues and eigenmatrices for  averages
! isothermal hydro
!
!-----------------------------------------------------------------------

d=>W(:,1); vx=>w(:,2)

!
! eigenvalues
!
!
  lambda(1,:) = vx - ISOTHERMAL_C
  lambda(2,:) = vx
  lambda(3,:) = vx
  lambda(4,:) = vx + ISOTHERMAL_C
!
! right eigenmatrix
!

  rem(1,1,:) = 1.
  rem(1,2,:) = -ISOTHERMAL_C/d
  rem(1,3,:) = 0.
  rem(1,4,:) = 0.

  rem(2,1,:) = 0.0
  rem(2,2,:) = 0.0
  rem(2,3,:) = 1.0
  rem(2,4,:) = 0.0

  rem(3,1,:) = 0.0
  rem(3,2,:) = 0.0
  rem(3,3,:) = 0.0
  rem(3,4,:) = 1.

  rem(4,1,:) = 1.
  rem(4,2,:) = -rem(1,2,:)
  rem(4,3,:) = 0.
  rem(4,4,:) = 0.
!
! left eigenmatrix
!

  lem(1,1,:) = .5
  lem(2,1,:) = -.5*d/ISOTHERMAL_C
  lem(3,1,:) = 0.0
  lem(4,1,:) = 0.0

  lem(1,2,:) = 0.0
  lem(2,2,:) = 0.0
  lem(3,2,:) = 1.0
  lem(4,2,:) = 0.0

  lem(1,3,:) = 0.0
  lem(2,3,:) = 0.0
  lem(3,3,:) = 0.0
  lem(4,3,:) = 1.0

  lem(1,4,:) =  .5
  lem(2,4,:) = -lem(2,1,:)
  lem(3,4,:) = 0.0
  lem(4,4,:) = 0.0

NULLIFY(d,vx)
return
end subroutine eigen_iso_hyd_prim
