subroutine get_slopes(NVAR,NX,w,dwc,dwl,dwr,dwg)
! 
! AUTHORS:
!     James M. Stone, Princeton Univeristy
!     Thomas Gardiner, University of Maryland
!     Peter J. Teuben, University of Maryland
!     John Hawley, University of Virginia
!
!     This software was produced with support from NSF Grant AST-0113571 
!
! Copyright 2003 James M. Stone, Thomas Gardiner,
!                Peter Teuben, John F. Hawley
!
!   This program is free software; you can redistribute it and/or modify
!   it under the terms of the GNU General Public License as published by
!   the Free Software Foundation.
!
!   This program is distributed in the hope that it will be useful,
!   but WITHOUT ANY WARRANTY; without even the implied warranty of
!   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
!   GNU General Public License for more details.
!
! This is an implementation of van Leer's harmonic mean 
! monotonic slope.  Other slope monotonic slope functions
! could be substituted, if desired.
!
! Input W:  state variable 
!
! Output : 
!    dwc =  centered non-monotonic slope
!    dwl =  left-centered non-monotonic slope
!    dwr =  right-centered non-monotonic slope
!    dwg =  centered monotonic slope
!

use athenadefs
IMPLICIT NONE

integer :: NVAR, NX
real (r_kind), dimension(NX,NVAR), intent(IN) :: w
real (r_kind), dimension(NX,NVAR), intent(OUT) :: dwc, dwl, dwr, dwg

!----------------------------------------------------------------------------

dwc = EOSHIFT(w,SHIFT=+1,DIM=1) - EOSHIFT(w,SHIFT=-1,DIM=1)
dwl = w - EOSHIFT(w,SHIFT=-1,DIM=1)
dwr = EOSHIFT(dwl,SHIFT=+1,DIM=1)

WHERE (dwl*dwr .gt. 0.) 
  dwg = 2.0_r_kind*dwl*dwr/(dwl+dwr)
ELSEWHERE
  dwg = 0.0
END WHERE


end subroutine get_slopes

