subroutine init_dt(agrid,courno)
!
!  Function INIT_DT
!  Computes initial timestep for a new run using CFL condition.  Thereafter,
!  dt is computed from maximum eigenvalue computed during update.
!
! Input variables
!   agrid = structure containing grid and grid variables
!   courno = courant number
!
! Output:  
!   computes and stores the intial timestep in agrid%dt
! 
! AUTHORS:
!     James M. Stone, Princeton Univeristy
!     Thomas Gardiner, University of Maryland
!     Peter J. Teuben, University of Maryland
!     John Hawley, University of Virginia
!
!     This software was produced with support from NSF Grant AST-0113571 
!
! Copyright 2003 James M. Stone, Thomas Gardiner,
!                Peter Teuben, John F. Hawley
!
!   This program is free software; you can redistribute it and/or modify
!   it under the terms of the GNU General Public License as published by
!   the Free Software Foundation.
!
!   This program is distributed in the hope that it will be useful,
!   but WITHOUT ANY WARRANTY; without even the implied warranty of
!   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
!   GNU General Public License for more details.
!

use athenadefs
IMPLICIT NONE

type(grid), intent(INOUT) :: agrid
real(r_kind), intent(IN) :: courno

! Local variables

integer          :: i

real(r_kind)  :: v1, v2, v3 , vmax
real(r_kind)  :: bsq, va
real(r_kind)  :: qsq, p , cs, cmax=0.0
!
!=============================================================================

   if (courno .GT. 1._r_kind) then
      write(*,*) "Warning!  Courant number greater than 1!"
   endif

   do i=agrid%is, agrid%ie

      v1 = agrid%m1(i)/agrid%d(i)
      v2 = agrid%m2(i)/agrid%d(i)
      v3 = agrid%m3(i)/agrid%d(i)
      vmax = max(abs(v1),max(abs(v2),abs(v3)))

      if (mhd) then
      bsq = agrid%b1(i)*agrid%b1(i) + agrid%b2(i)*agrid%b2(i) &
          + agrid%b3(i)*agrid%b3(i)
      va = sqrt(bsq/agrid%d(i))
    
      else
      bsq = 0.0
      va = 0.0
       
      endif

      if (adiabatic) then

      qsq = v1*v1 + v2*v2 + v3*v3
      p = max((agrid%gamma-1._r_kind)&
          *(agrid%e(i)-0.5*agrid%d(i)*qsq-0.5_r_kind*bsq), TINY_NUMBER)
      cs = sqrt(agrid%gamma*p/agrid%d(i))
   
      else
      cs = ISOTHERMAL_C

      endif

      cmax = max(cmax, cs + va + vmax)

   enddo

   agrid%dt = COURNO*agrid%dx/cmax; 

end subroutine init_dt
