SUBROUTINE problem(agrid)
!
! Initialize user defined problems
! This version is the Colella-Woodward strong blast problem
! with two pressure discontinuities
!
! 
! AUTHORS:
!     James M. Stone, Princeton Univeristy
!     Thomas Gardiner, University of Maryland
!     Peter J. Teuben, University of Maryland
!     John Hawley, University of Virginia
!
!     This software was produced with support from NSF Grant AST-0113571 
!
! Copyright 2003 James M. Stone, Thomas Gardiner,
!                Peter Teuben, John F. Hawley
!
!   This program is free software; you can redistribute it and/or modify
!   it under the terms of the GNU General Public License as published by
!   the Free Software Foundation.
!
!   This program is distributed in the hope that it will be useful,
!   but WITHOUT ANY WARRANTY; without even the implied warranty of
!   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
!   GNU General Public License for more details.
!

use athenadefs
IMPLICIT NONE
type (grid) agrid

real (r_kind) :: gamma, dl, pl, v1l, v2l, v3l, b1l, b2l, b3l 
real (r_kind) :: dr, pr, v1r, v2r, v3r, b1r, b2r, b3r 

integer :: i, is, ie, nx1, nhalf
real (r_kind) :: dx

namelist /prob/ gamma, dl, pl, v1l, v2l, v3l, b1l, b2l, b3l &
                     , dr, pr, v1r, v2r, v3r, b1r, b2r, b3r 
!------------------------------------------------------------------------
!

write(*,*) 'CW Blast initial setup'

if (mhd .or. (.not. adiabatic)) then
   write(*,*) 'CW blastwave is an adiabatic hydro problem'
   write(*,*) 'Current code is MHD = ', MHD
   write(*,*) ' ADIABATIC = ', ADIABATIC
   stop
endif

open(unit=12, file='athena.input',status='OLD')
read(12,nml=PROB)
close(12)

nx1 = agrid%nx1
is = NGHOST+1
ie = nx1-NGHOST
agrid%is = is
agrid%ie = ie
dx = agrid%dx
agrid%x1(is) = agrid%x1_0+0.5*dx
do i=1,NGHOST
  agrid%x1(is-i) = agrid%x1(is-i+1)-dx
end do
do i=is+1,nx1
  agrid%x1(i) = agrid%x1(i-1)+dx
end do

write(*,*) 'gamma = ', gamma

agrid%gamma = gamma
agrid%d = 1.
agrid%m1 = 0.
agrid%m2 = 0.
agrid%m3 = 0.

if (mhd) then
  agrid%b1 = b1l
  agrid%b2 = b2l
  agrid%b3 = b3l
endif

if (adiabatic) then
  do i=1,NX1
     if (agrid%x1(i) .le. 0.1_r_kind) then
        agrid%e(i) = 1000./(gamma-1.)
     else if (agrid%x1(i) .ge. 0.9_r_kind) then
        agrid%e(i) = 100./(gamma-1.)
     else
        agrid%e(i) = 0.01/(gamma-1.)
     endif
  enddo
endif

return

END SUBROUTINE problem
