SUBROUTINE problem(agrid)
!
! Initialize user defined problems
! This version is a generalized shock tube
! with one discontinuity located at the middle of the grid
!
! 
! AUTHORS:
!     James M. Stone, Princeton Univeristy
!     Thomas Gardiner, University of Maryland
!     Peter J. Teuben, University of Maryland
!     John Hawley, University of Virginia
!
!     This software was produced with support from NSF Grant AST-0113571 
!
! Copyright 2003 James M. Stone, Thomas Gardiner,
!                Peter Teuben, John F. Hawley
!
!   This program is free software; you can redistribute it and/or modify
!   it under the terms of the GNU General Public License as published by
!   the Free Software Foundation.
!
!   This program is distributed in the hope that it will be useful,
!   but WITHOUT ANY WARRANTY; without even the implied warranty of
!   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
!   GNU General Public License for more details.
!

use athenadefs
IMPLICIT NONE
type (grid) agrid

real (r_kind) :: gamma, dl, pl, v1l, v2l, v3l, b1l, b2l, b3l 
real (r_kind) :: dr, pr, v1r, v2r, v3r, b1r, b2r, b3r 

integer :: i, is, ie, nx1, nhalf
real (r_kind) :: dx

namelist /prob/ gamma, dl, pl, v1l, v2l, v3l, b1l, b2l, b3l &
                     , dr, pr, v1r, v2r, v3r, b1r, b2r, b3r 
!------------------------------------------------------------------------
!

open(unit=12, file='athena.input',status='OLD')
read(12,nml=PROB)
close(12)

nx1 = agrid%nx1
is = NGHOST+1
ie = nx1-NGHOST
agrid%is = is
agrid%ie = ie
dx = agrid%dx
nhalf = is+(ie-is+1)/2-1
agrid%x1(is) = agrid%x1_0+0.5*dx
do i=1,NGHOST
  agrid%x1(is-i) = agrid%x1(is-i+1)-dx
end do
do i=is+1,nx1
  agrid%x1(i) = agrid%x1(i-1)+dx
end do

write(*,*) 'gamma = ', gamma

agrid%gamma = gamma
agrid%d(1:nhalf) = dl
agrid%d(nhalf+1:nx1) = dr
agrid%m1(1:nhalf) = dl*v1l
agrid%m1(nhalf+1:nx1) = dr*v1r
agrid%m2(1:nhalf) = dl*v2l
agrid%m2(nhalf+1:nx1) = dr*v2r
agrid%m3(1:nhalf) = dl*v3l
agrid%m3(nhalf+1:nx1) = dr*v3r

if (mhd) then
  agrid%b1(1:nhalf) = b1l
  agrid%b1(nhalf+1:nx1) = b1r
  agrid%b2(1:nhalf) = b2l
  agrid%b2(nhalf+1:nx1) = b2r
  agrid%b3(1:nhalf) = b3l
  agrid%b3(nhalf+1:nx1) = b3r
endif

if (adiabatic) then
  if (mhd) then
    agrid%e(1:nhalf) = pl/(gamma-1._r_kind) &
         + 0.5_r_kind*(b1l*b1l + b2l*b2l + b3l*b3l)&
         + 0.5_r_kind*(v1l*v1l + v2l*v2l + v3l*v3l)*dl
    agrid%e(nhalf+1:nx1) = pr/(gamma-1._r_kind) &
         + 0.5_r_kind*(b1r*b1r + b2r*b2r + b3r*b3r)&
         + 0.5_r_kind*(v1r*v1r + v2r*v2r + v3r*v3r)*dr
  else
    agrid%e(1:nhalf) = pl/(gamma-1._r_kind) &
         + 0.5_r_kind*(v1l*v1l + v2l*v2l + v3l*v3l)*dl
    agrid%e(nhalf+1:nx1) = pr/(gamma-1._r_kind) &
         + 0.5_r_kind*(v1r*v1r + v2r*v2r + v3r*v3r)*dr
  endif
endif

return

END SUBROUTINE problem
